<template>
  <div class="linechar"
       ref="chart"></div>
</template>

<script>
import * as echarts from "echarts"
import {
  countCountryDimension,
  countProvinceDimension,
  GetServicesVisitsCount,
  countZhPipeMapLength,
  countLargeCategories,
  countProjectType,
  countProjectDown,
  countProjectTypeNumber,
  countStorageByProject,
} from "@/api/screen.js"
export default {
  props: {
    width: {
      type: String,
      default: "100%",
    },
    height: {
      type: String,
      default: "100%",
    },
    autoResize: {
      type: Boolean,
      default: true,
    },
    // option: {
    //   type: Object,
    //   required: true
    // },
    type: {
      type: String,
      default: "canvas",
    },
    project: {
      type: String,
      default: "全国项目",
    },
    params: {
      type: Object,
      default: () => null,
    },
    project: {
      type: String,
      default: "全国项目",
    },
    title: {
      type: String,
      default: "",
    },
  },
  data () {
    return {
      chart: null,
      dataList: [],
    }
  },
  computed: {
    option () {
      let xAxis=[]
      let yAxis=[]
      const proObj=this.dataList.find(item => item.项目名称==this.project)
      if(proObj) {
        Object.keys(proObj).forEach(item => {
          if(item.toString()!='项目名称') {
            xAxis.push(item)
            yAxis.push(proObj[item])
          }
        })
      } else {
        this.dataList.forEach(item => {
          let type=item.type||item.projtype
          xAxis.push(type)
          yAxis.push(item.count)
        })
      }

      // let data = [220, 182, 191, 234, 290, 330, 310]
      // const sideData = data.map(item => {
      //   return {
      //     name: item.name,
      //     value: item.number,
      //   }
      // })

      var obj=[];
      for(var i in xAxis) {
        if(xAxis[i]) {
          obj.push(xAxis[i])
        } else {
          obj.push("其他")
        }
      }

      xAxis=obj
      let option={
        tooltip: {
          trigger: "axis",
        },
        grid: {
          right: "5%",
          top: "10%",
          left: "5%",
          bottom: "17%",
          containLabel: true,
        },

        xAxis: {
          type: "category",
          boundaryGap: true,
          axisLine: {
            lineStyle: {
              color: "#fff",
            },
            show: false,
          },
          nameRotate: 45,
          axisTick: {
            show: false,
            alignWithLabel: true,
          },
          axisLabel: {
            fontFamily: "PingFangSC-Regular",
          },
          data: xAxis,
        },
        yAxis: {
          axisLine: {
            show: false,
            lineStyle: {
              color: "#fff",
            },
          },
          axisLabel: {
            fontFamily: "Roboto-Regular",
          },
          axisTick: {
            show: false,
          },
          // 分割线
          splitLine: {
            lineStyle: {
              color: "#5d7289",
              width: 1,
              type: "dashed",
            },
          },
          type: "value",
        },
        series: [
          {
            name: this.title,
            type: "line",
            showAllSymbol: false,
            lineStyle: {
              color: "#2579D8",
            },
            itemStyle: {
              color: "#2579D8",
            },
            smooth: 0.2,
            data: yAxis,
          },
        ],
      }

      return option
    },
  },
  watch: {
    option: {
      deep: true,
      handler (newVal) {
        this.setOptions(newVal)
      },
    },
    project: {
      deep: true,
      immediate: true,
      handler (newVal) {
        let requsetFn=null
        switch(newVal) {
          case "全球项目":
            requsetFn=countProjectTypeNumber
            break
          case "全国项目":
            requsetFn=countProjectTypeNumber
            break
          case "全球管网图":
            requsetFn=countZhPipeMapLength
            break
          case "全国管网图":
            requsetFn=countZhPipeMapLength
            break
          default:
            requsetFn=countStorageByProject

            break
        }
        requsetFn&&this.initData(requsetFn)

        this.setOptions(this.option)
      },
    },
  },
  mounted () {
    // this.initData()
    this.initChart()
    if(this.autoResize) {
      window.addEventListener("resize",this.resizeHandler)
    }
  },
  beforeDestroy () {
    if(!this.chart) {
      return
    }
    if(this.autoResize) {
      window.removeEventListener("resize",this.resizeHandler)
    }
    this.chart.dispose()
    this.chart=null
  },
  methods: {
    resizeHandler () {
      this.chart&&this.chart.resize()
    },
    initChart () {
      this.chart=echarts.init(this.$refs.chart,"",{
        renderer: this.type,
      })
      this.chart.setOption(this.option)
      this.chart.on("click",this.handleClick)
    },
    handleClick (params) {
      this.$emit("click",params)
    },
    setOptions (option) {
      this.clearChart()
      this.resizeHandler()
      if(this.chart) {
        this.chart.setOption(option)
      }
    },
    refresh () {
      this.setOptions(this.option)
    },
    clearChart () {
      this.chart&&this.chart.clear()
    },
    async initData (requsetFn=GetServicesVisitsCount) {
      const res=await requsetFn(this.params)
      if(res.code==200) {
        this.dataList=res.result
        console.log("requsetFn",res)
      }
    },
  },
}
</script>

<style lang="scss" scoped>
.linechar {
  width: 100%;
  height: 100%;
}
</style>
